****
Micc
****

This is work in progress!

.. image:: https://img.shields.io/pypi/v/micc.svg
        :target: https://pypi.python.org/pypi/micc

.. image:: https://img.shields.io/travis/etijskens/micc.svg
        :target: https://travis-ci.org/etijskens/micc

.. image:: https://readthedocs.org/projects/micc/badge/?version=latest
        :target: https://micc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


*Micc* is a Python project manager: it can

* create new projects
* add python modules and applications
* add and build binary extension modules written in C++ and Fortran.
* build documentation (using `sphinx <http://www.sphinx-doc.org/>`_)
* do version management and control (using `git <https://www.git-scm.com/>`_)
* test your code (using `pytest <https://www.git-scm.com/>`_)


TODO 

* facilitates publishing, e.g. `readthedocs <https://readthedocs.org>`_, `PyPI <https://pypi.org>`_  
* facilitates CI

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
